Module: Contrast::Utils::CEFLogUtils
- Includes:
- LogUtils
- Included in:
- Agent::RequestContextExtend, Logger::CEFLog
- Defined in:
- lib/contrast/utils/log_utils.rb
Overview
These are the utilities for the CEF Logger, which will use the default ruby logger as we are not interested in special logging. We have the format we need and that's all we need. It would be useless to use Ougai
Constant Summary collapse
- DEFAULT_CEF_NAME =
CEF: | | | | | | | 'security.log'- DEFAULT_LEVEL =
::Logger::Severity::INFO
- VALID_LEVELS =
::Logger::SEV_LABEL
- PROGNAME =
'Contrast Agent Ruby'- DATE_TIME_FORMAT =
'%b %d %Y %H:%M:%S.%L%z'- AGENT_VERSION =
Contrast::Agent::VERSION
- EVENT_TYPE =
'SECURITY'- DEFAULT_METADATA =
'-'
Constants included from LogUtils
LogUtils::DEFAULT_NAME, LogUtils::STDERR_STR, LogUtils::STDOUT_STR